/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void setColor();
   QLineEdit *text_1;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   // text edit
   text_1 = new QLineEdit();
   text_1->setText("Sample text to show a background color");
   text_1->setMinimumSize(400, 35);

   // two buttons
   QPushButton *pb_1 = new QPushButton();
   pb_1->setText("Show Colors");

   QPushButton *pb_2 = new QPushButton();
   pb_2->setText("Close");

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addSpacing(75);
   layout1->addWidget(text_1);
   layout1->addSpacing(75);

   QHBoxLayout *layout2 = new QHBoxLayout();
   layout2->addStretch();
   layout2->addWidget(pb_1);
   layout2->addSpacing(10);
   layout2->addWidget(pb_2);
   layout2->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(layout1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout2);

   QObject::connect(pb_1, &QPushButton::clicked, this, &MainWindow::setColor);
   QObject::connect(pb_2, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::setColor()
{
   QColor color;
   color = QColorDialog::getColor(Qt::green, this);

   if (color.isValid()) {
      QPalette tmp = text_1->palette();
      tmp.setColor(QPalette::Base, color);

      text_1->setPalette(tmp);
   }
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

